.. _data-autodoc:

######
 Data
######

.. automodule:: anemoi.datasets.data.__init__
   :members:
   :no-undoc-members:
   :show-inheritance:

.. automodule:: anemoi.datasets.data.dataset
   :members:
   :no-undoc-members:
   :show-inheritance:
